@@ -26,7 +26,7 @@ class AutoMapperSplitByDelimiterDataType(AutoMapperArrayLikeBase):
         ) else f"[{delimiter}]"
 
     def get_column_spec(
-        self, source_df: DataFrame, current_column: Optional[Column]
+        self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
         column_spec = split(
             self.column.get_column_spec(
